@import "sphinx-book-theme.css";

/* for the sphinx design cards */
body {
    --sd-color-shadow: dimgrey;
}

dl.citation > dt {
    float: left;
    margin-right: 15px;
    font-weight: bold;
}

/* for custom small role */
.small {
    font-size: 40% !important;
}

.smaller,
.pr {
    font-size: 70% !important;
}

/* Fix pydata theme search button changing size */
.search-button-field {
    border: 0;
    outline: 1px solid var(--pst-color-border);
}
.search-button-field:hover {
    border: 0;
    outline: 2px solid var(--pst-color-link-hover);
}

/* Make the readthedocs-sphinx-search popup adapt to the theme */
/*backdrop*/
html[data-theme] .search__backdrop {
    z-index: 1020;
    backdrop-filter: saturate(150%) blur(20px);
}
/*container*/
html[data-theme] :is(.search__outer, .rtd__search__credits) {
    font-family: var(--pst-font-family-base);
    color: var(--pst-color-text-base);
    background-color: var(--pst-color-background);
    border-color: var(--pst-color-border);
}
html[data-theme] .search__outer {
    border-top-left-radius: var(--bs-border-radius);
    border-top-right-radius: var(--bs-border-radius);
}
html[data-theme] .rtd__search__credits {
    border-bottom-left-radius: var(--bs-border-radius);
    border-bottom-right-radius: var(--bs-border-radius);
}
html[data-theme] .rtd__search__credits a {
    color: var(--pst-color-link);
}
/*icons*/
html[data-theme] .search__outer::before {
    /* this can’t be put on .search__outer__input, as <input/> supports no ::before */
    position: absolute;
    padding: 0.4em 0.3em;
    content: "\f002"; /* fa-magnifying-glass */
    font: var(--fa-font-solid);
    color: var(--pst-color-text-muted);
}
html[data-theme] .search__cross__img polygon {
    fill: currentcolor;
}
/*input*/
html[data-theme] .search__outer__input {
    color: var(--pst-color-text-base);
    background-image: none; /* hide the default search icon */
    background-color: transparent;
    border-bottom-color: var(--pst-color-border);
}
html[data-theme] .search__outer .bar::before,
html[data-theme] .search__outer .bar::after {
    background-color: var(--pst-color-accent);
}
/*results*/
html[data-theme] :is(.search__result__subheading span, .search__result__single) {
    border-bottom-color: var(--pst-color-border);
}
html[data-theme] .search__result__single:last-of-type {
    border-bottom-width: 0;
}
html[data-theme] :is(.outer_div_page_results:hover, .search__result__box .active) {
    background-color: var(--pst-color-accent-bg);
}
html[data-theme]
    :is(.search__error__box, .search__result__subheading, .search__result__content) {
    color: var(--pst-color-text-base);
}
html[data-theme]
    .search__outer
    :is(.search__result__content, .search__result__title)
    span {
    border-bottom-color: var(--pst-color-border);
    background-color: var(--pst-color-target);
}
